==> nted_0.24.1.orig.tar.gz: nted-0.24.1/commands/paperconfigcommand.h <==
/****************************************************************************************/
/*											*/
/* This program is free software; you can redistribute it and/or modify it under the	*/
/* terms of the GNU General Public License as published by the Free Software		*/
/* Foundation; either version 2 of the License, or (at your option) any later version.	*/
/*											*/
/* This program is distributed in the hope that it will be useful, but WITHOUT ANY	*/
/* WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A	*/
/* PARTICULAR PURPOSE. See the GNU General Public License for more details.		*/
/*											*/
/* You should have received a copy of the GNU General Public License along with this	*/
/* program; (See "COPYING"). If not, If not, see <http://www.gnu.org/licenses/>.        */
/*											*/
/*--------------------------------------------------------------------------------------*/
/*											*/
/*  Copyright   Joerg Anders, TU Chemnitz, Fakultaet fuer Informatik, GERMANY           */
/*		ja@informatik.tu-chemnitz.de						*/
/*											*/
/*											*/
/****************************************************************************************/

#ifndef PAPER_CONFIG_COMMAND_H

#define PAPER_CONFIG_COMMAND_H
#include "config.h"
#include "command.h"
#include <gtk/gtk.h>

class NedMainWindow;
struct paper_info_struct;


class NedPaperConfigCommand : public NedCommand {
	public:	
		NedPaperConfigCommand(NedMainWindow *main_window, struct paper_info_struct *old_paper_info, bool old_portrait,
			struct paper_info_struct *new_paper_info, bool new_portrait);
		virtual void execute(bool adjust = false);
		virtual void unexecute(bool adjust = false);
	private:
		NedMainWindow *m_main_window;
		struct paper_info_struct *m_old_paper_info, *m_new_paper_info;
		bool m_old_portrait, m_new_portrait;
};

#endif /* PAPER_CONFIG_COMMAND_H */

==> nted_1.10.18.orig.tar.gz: nted-1.10.18/commands/paperconfigcommand.h <==
/****************************************************************************************/
/*											*/
/* This program is free software; you can redistribute it and/or modify it under the	*/
/* terms of the GNU General Public License as published by the Free Software		*/
/* Foundation; either version 2 of the License, or (at your option) any later version.	*/
/*											*/
/* This program is distributed in the hope that it will be useful, but WITHOUT ANY	*/
/* WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A	*/
/* PARTICULAR PURPOSE. See the GNU General Public License for more details.		*/
/*											*/
/* You should have received a copy of the GNU General Public License along with this	*/
/* program; (See "COPYING"). If not, If not, see <http://www.gnu.org/licenses/>.        */
/*											*/
/*--------------------------------------------------------------------------------------*/
/*											*/
/*  Copyright   Joerg Anders, TU Chemnitz, Fakultaet fuer Informatik, GERMANY           */
/*		ja@informatik.tu-chemnitz.de						*/
/*											*/
/*											*/
/****************************************************************************************/

#ifndef PAPER_CONFIG_COMMAND_H

#define PAPER_CONFIG_COMMAND_H
#include "config.h"
#include "command.h"
#include <gtk/gtk.h>

class NedMainWindow;
struct paper_info_struct;


class NedPaperConfigCommand : public NedCommand {
	public:	
		NedPaperConfigCommand(NedMainWindow *main_window, struct paper_info_struct *old_paper_info, bool old_portrait,
			struct paper_info_struct *new_paper_info, bool new_portrait, int oldscale, int scale);
		virtual void execute(bool adjust = false);
		virtual void unexecute(bool adjust = false);
	private:
		NedMainWindow *m_main_window;
		struct paper_info_struct *m_old_paper_info, *m_new_paper_info;
		bool m_old_portrait, m_new_portrait;
		int m_scale, m_old_scale;
};

#endif /* PAPER_CONFIG_COMMAND_H */
